@@ -23,45 +23,26 @@
 
 #include "cssgeneratorfactory.h"
 
-#include "cssdecorator.h"
-
-// the createXXXXDecorator must not be called, since the more general
-// method, createGenerator, is redefined for CSS.
+#include "tags.h"
+#include "cssgeneratormap.h"
+#include "htmltaggen.h"
+#include "xhtmltags.h"
+#include "textgen.h"
 
 TextGenerator *
-CssGeneratorFactory::createBoldDecorator(TextGenerator *gen)
+CssGeneratorFactory::createGenerator( const string &key )
 {
-  assert (0);
-
-  return 0;
+  return new TextGenerator( startTAG(SPAN_TAG, "class", key), endTAG(SPAN_TAG) ) ;
 }
 
 TextGenerator *
-CssGeneratorFactory::createItalicDecorator(TextGenerator *gen)
+CssGeneratorFactory::createGenerator( const Tag *tag )
 {
-  assert (0);
-
-  return 0;
+  return createGenerator( tag->GetName() ) ;
 }
 
-TextGenerator *
-CssGeneratorFactory::createUnderlineDecorator(TextGenerator *gen)
+GeneratorMap *
+CssGeneratorFactory::createGeneratorMap()
 {
-  assert (0);
-
-  return 0;
-}
-
-TextGenerator *
-CssGeneratorFactory::createColorDecorator(TextGenerator *gen, const string &color)
-{
-  assert (0);
-
-  return 0;
-}
-
-TextGenerator *
-CssGeneratorFactory::createGenerator( TextGenerator *final_dec, const string &key )
-{
-  return new SpanDecorator( final_dec, char_translator, key ) ;
+  return new CssGeneratorMap;
 }
