@@ -21,36 +21,10 @@
 
 #include "xhtmlgeneratorfactory.h"
 
-#include "xhtmldecorator.h"
 #include "xhtmltags.h"
+#include "htmltags.h"
 #include "xhtmldocgenerator.h"
-
-TextGenerator *
-XHtmlGeneratorFactory::createBoldDecorator(TextGenerator *gen)
-{
-  return new XhtmlTagDecorator( gen, char_translator, SPAN_TAG,
-                                XHTML_BOLD_TAG, XHTML_BOLD_VAL ) ;
-}
-
-TextGenerator *
-XHtmlGeneratorFactory::createItalicDecorator(TextGenerator *gen)
-{
-  return new XhtmlTagDecorator( gen, char_translator, SPAN_TAG,
-                                XHTML_ITALIC_TAG, XHTML_ITALIC_VAL ) ;
-}
-
-TextGenerator *
-XHtmlGeneratorFactory::createUnderlineDecorator(TextGenerator *gen)
-{
-  return new XhtmlTagDecorator( gen, char_translator, SPAN_TAG,
-                                XHTML_UNDERLINE_TAG, XHTML_UNDERLINE_VAL ) ;
-}
-
-TextGenerator *
-XHtmlGeneratorFactory::createColorDecorator(TextGenerator *gen, const string &color)
-{
-  return new XhtmlColorDecorator( gen, char_translator, color ) ;
-}
+#include "htmltaggen.h"
 
 DocGenerator *
 XHtmlGeneratorFactory::createDocGenerator()
@@ -58,3 +32,37 @@ XHtmlGeneratorFactory::createDocGenerator()
   return new XHtmlDocGenerator (title, input_file_name, doc_header, doc_footer,
                                css_url);
 }
+
+const string
+generateXHtmlTag(const string &attr, const string &val)
+{
+  return startTAG(SPAN_TAG, "style", attr + ": " + val);
+}
+
+void
+XHtmlGeneratorFactory::addBold()
+{
+  addStartTag(generateXHtmlTag(XHTML_BOLD_TAG, XHTML_BOLD_VAL));
+  addCloseTag(endTAG(SPAN_TAG));
+}
+
+void
+XHtmlGeneratorFactory::addItalic()
+{
+  addStartTag(generateXHtmlTag(XHTML_ITALIC_TAG, XHTML_ITALIC_VAL));
+  addCloseTag(endTAG(SPAN_TAG));
+}
+
+void
+XHtmlGeneratorFactory::addUnderline()
+{
+  addStartTag(generateXHtmlTag(XHTML_UNDERLINE_TAG, XHTML_UNDERLINE_VAL));
+  addCloseTag(endTAG(SPAN_TAG));
+}
+
+void
+XHtmlGeneratorFactory::addColor(const string &color)
+{
+  addStartTag(generateXHtmlTag(COLOR_TAG, color));
+  addCloseTag(endTAG(SPAN_TAG));  
+}
