@@ -29,15 +29,17 @@
 #include "tags.h"
 #include "keys.h"
 #include "textgen.h"
-#include "decorators.h"
 #include "fileutil.h"
-#include "linenogen.h"
 #include "docgenerator.h"
+#include "lineoutputgenerator.h"
 
 // globals
 #include "linenumdigit.h"
 #include "cmdlineargs.h"
 #include "scanner_map.h"
+#include "generators.h"
+#include "mainoutputbuffer.h"
+#include "mainoutputgenerator.h"
 
 #ifdef HAVE_CONFIG_H
 #include "config.h"
@@ -64,7 +66,7 @@ static char *get_input_file_name(const char *file_name);
 void
 processFile( const char *source_language, const char *output_format,
              const char *inputFileName, const char *outputFileName,
-             short entire_doc, bool gen_version )
+             short entire_doc, bool gen_version, bool gen_line, bool gen_ref )
 {
   FILE *in = 0;
   bool deleteOStream = false ;
@@ -100,7 +102,7 @@ processFile( const char *source_language, const char *output_format,
       const char *input_file_name = get_input_file_name (inputFileName);
 
       in = freopen (input_file_name, "r", stdin);
-      if (!in) 
+      if (!in)
         {
           cerr << "Error in opening " << inputFileName
                << " for input" << endl ;
@@ -121,6 +123,11 @@ processFile( const char *source_language, const char *output_format,
     ; /* Well stdin already points to stdin so, .... */
   }
 
+  if (gen_line)
+    outputgenerator = new LineOutputGenerator(*outputbuffer, *sout, gen_ref);
+  else
+    outputgenerator = new OutputGenerator(*outputbuffer, *sout);
+
   if ( entire_doc ) {
     GlobalDocGenerator->set_gen_version (gen_version);
     GlobalDocGenerator->generate_top ();
@@ -141,8 +148,6 @@ processFile( const char *source_language, const char *output_format,
 
   GlobalDocGenerator->generate_start_doc ();
 
-  LineNumberDecorator::reset ();
-
   // decide which lexer to call
   ScannerMap scanner_map;
 
@@ -151,19 +156,27 @@ processFile( const char *source_language, const char *output_format,
       if (! scanner_map.invoke_scanner (source_language))
         {
           cerr << PACKAGE << ": ";
-          cerr << "source language " << source_language 
+          cerr << "source language " << source_language
                << " not handled" << endl;
           exit (1);
         }
     }
   else
     {
+      if (! inputFileName)
+        {
+          cerr << PACKAGE << ": ";
+          cerr << "when using stdin, please specify a source language"
+               << endl;
+          exit (1);
+        }
+
       string file_ext = get_file_extension (inputFileName);
 
       if (file_ext == "")
         {
           cerr << PACKAGE << ": ";
-          cerr << "no file extension; please specify a source language" 
+          cerr << "no file extension; please specify a source language"
                << endl;
           exit (1);
         }
@@ -176,6 +189,8 @@ processFile( const char *source_language, const char *output_format,
         }
     }
 
+  outputgenerator->generate();
+
   GlobalDocGenerator->generate_end_doc ();
 
   printMessage( "done !", cerr ) ;
@@ -189,6 +204,8 @@ processFile( const char *source_language, const char *output_format,
   if ( deleteOStream )
     delete sout ;
 
+  delete outputgenerator;
+
 //----------------------------------------------------------------------------//
 //	Don Stauffer																								June 2003
 //----------------------------------------------------------------------------//
@@ -233,9 +250,9 @@ generateln (const char *s)
   pretranslator->generateln (s);
 }
 
-void 
+void
 generate_preproc ( const char  *s )
-{ 
+{
   pretranslator->generate_preproc (s);
 }
 
@@ -246,7 +263,7 @@ generate_normal	(const char *s)
 }
 
 void
-generateNewLine	(const char *s)	
+generateNewLine	(const char *s)
 {
   if (s)
     {
@@ -292,68 +309,110 @@ endComment(const char *s)
   pretranslator->endComment(s);
 }
 
-void 
+void
 generateComment(const char *s)
-{	
+{
   pretranslator->generateComment(s);
 }
 
 void
 startString(const char *s)
-{	
+{
   pretranslator->startString(s);
 }
 
 void
 endString(const char *s)
-{	
+{
   pretranslator->endString(s);
 }
 
 void
 generateString(const char *s)
-{	
+{
   pretranslator->generateString(s);
 }
 
 void
 generateKeyWord(const char *s)
-{	
+{
   pretranslator->generateKeyWord(s);
 }
 
 void
 generateBaseType(const char *s)
-{	
+{
   pretranslator->generateBaseType(s);
 }
 
 void
 generatePreProc(const char *s)
-{	
+{
   pretranslator->generatePreProc(s);
 }
 
 void
 generateNumber(const char *s)
-{	
+{
   pretranslator->generateNumber(s);
 }
 
 void
 generateSymbol(const char *s)
-{	
+{
   pretranslator->generateSymbol(s);
 }
 
 void
 generateFunction(const char *s)
-{	
+{
   pretranslator->generateFunction(s);
 }
 
 void
 generateCBracket(const char *s)
-{	
+{
   pretranslator->generateCBracket(s);
 }
+
+void
+generate( const char * elem, const char * s )
+{
+  pretranslator->generate(elem, s);
+}
+
+void
+generate( const char * elem, const char * s, int start, int end )
+{
+  pretranslator->generate(elem, s, start, end);
+}
+
+void
+generate_preproc(const char * elem, const char * s)
+{
+  pretranslator->generate_preproc(elem, s);
+}
+
+void
+generateln( const char * elem, const char * s )
+{
+  pretranslator->generateln(elem, s);
+}
+
+void
+generateEntire( const char * elem, const char * s )
+{
+  pretranslator->generateEntire(elem, s);
+}
+
+void
+beginText( const char * elem, const char * s )
+{
+  pretranslator->beginText(elem, s);
+}
+
+void
+endText( const char * elem, const char * s )
+{
+  pretranslator->endText(elem, s);
+}
