@@ -92,6 +92,7 @@
  */
 
 #include <stdio.h>
+#include <stdlib.h>
 #include <string.h>
 #include <iostream>
 
@@ -108,9 +109,10 @@ using std::cerr;
 static int opsc_parse() ;
 static void opsc_error( char *s ) ;
 
-int line = 0 ;
+int line = 1 ;
 
 static FILE *openTagsFile() ;
+static void add_tag(Tags *tags, Tag *t);
 
 extern int opsc_lex() ;
 extern FILE *opsc_in ;
@@ -321,8 +323,8 @@ static const opsc_signed_char yyrhs[] =
 /* YYRLINE[YYN] -- source line where rule number YYN was defined.  */
 static const unsigned char yyrline[] =
 {
-       0,    64,    64,    67,    68,    72,    71,    83,    84,    87,
-      88,    89,    90
+       0,    66,    66,    69,    70,    74,    73,    85,    86,    89,
+      90,    91,    92
 };
 #endif
 
@@ -1027,7 +1029,7 @@ yyreduce:
 
   case 3:
 
-    { opsc_vsp[-1].tags->AddTag( opsc_vsp[0].tag ) ; }
+    { add_tag( opsc_vsp[-1].tags, opsc_vsp[0].tag ) ; }
     break;
 
   case 4:
@@ -1285,11 +1287,11 @@ yyreturn:
 #define TAGS_FILE "tags.j2h"
 
 extern char *tags_file;
+char *current_file = 0;
 
 void
 parseTags()
 {
-
   // opens the file for opsc_lex
   opsc_in = openTagsFile() ;
   if (! opsc_in) {
@@ -1299,10 +1301,11 @@ parseTags()
   }
 
   printMessage_noln( "Parsing ", cerr ) ;
-  if (tags_file)
+  if (tags_file) {
     printMessage_noln (tags_file, cerr);
-  else
+  } else {
     printMessage_noln (TAGS_FILE, cerr);
+  }
   printMessage( " file ...", cerr ) ;
   opsc_parse() ;
   printMessage( "Parsing done!", cerr ) ;
@@ -1319,17 +1322,20 @@ openTagsFile()
     {
       printMessage (tags_file);
       file = fopen (tags_file, "r");
+      current_file = tags_file;
       if (file)
         return file;
     }
 
   printMessage( TAGS_FILE ) ;
   file = fopen( TAGS_FILE, "r") ;
+  current_file = TAGS_FILE;
   if ( file )
     return file ;
 
   file = fopen( SOURCE_HIGHLIGHT_DATA_DIR "/" TAGS_FILE, "r") ;
   printMessage( SOURCE_HIGHLIGHT_DATA_DIR "/" TAGS_FILE ) ;
+  current_file = SOURCE_HIGHLIGHT_DATA_DIR "/" TAGS_FILE;
 
   return file ;
 }
@@ -1338,8 +1344,16 @@ void
 opsc_error( char *s )
 {
   ostringstream str ;
-  str << "*** " << s << " on option # " << line;
+  str << current_file << ":" << line << ": " << s << ", in option declaration";
   printError( str.str().c_str(), cerr ) ;
-  printError( "Using default tags...", cerr ) ;
+  exit(EXIT_FAILURE);
 }
 
+void
+add_tag(Tags *tags, Tag *t)
+{
+  if (! tags->AddTag(t))
+  {
+    opsc_error("already defined");
+  }
+}
