@@ -21,64 +21,130 @@
 
 #include "textgen.h"
 #include "chartranslator.h"
+#include "maingeneratorfactory.h"
 
-#include "globalostream.h"
+using namespace std;
 
-using std::endl;
+TextGenerator::TextGenerator() :
+  char_translator (generator_factory->getCharTranslator())
+{
+}
 
-TextGenerator::TextGenerator(CharTranslator *trans) :
-  char_translator (trans)
+TextGenerator::TextGenerator(const std::string &pre, const std::string &post) : 
+  pre_tag(pre), post_tag(post),
+  char_translator (generator_factory->getCharTranslator())
 {
 }
 
 void
+TextGenerator::output(const string &s)
+{
+  outstream << s;
+}
+
+void
+TextGenerator::output_ln(const string &s)
+{
+  outstream << s << endl;
+}
+
+void
+TextGenerator::output(int i)
+{
+  outstream << i;
+}
+
+void
+TextGenerator::reset()
+{
+  outstream.str("");
+}
+
+string
 TextGenerator::generate(const char *s)
 {
-  (*sout) << s ;
+  reset();
+  output(s);
+  return outstream.str();
+}
+
+string
+TextGenerator::generate( const string &s, int start, int end )
+{
+  reset();
+  output(s.substr(start, end-start));
+  return outstream.str();
 }
 
 void
-TextGenerator::generate( const char *s, int start, int end )
+TextGenerator::preprocess(const char *s)
 {
-  for ( int i = start ; i <= end ; ++i )
-    (*sout) << s[i] ;
+  char_translator->translate (&outstream, s);
 }
 
 // this version preprocess the string for some special characters
-void
+string
 TextGenerator::generate_preproc(const char *s)
 {
-  char_translator->translate (sout, s);
+  reset();
+  preprocess(s);
+  return outstream.str();
 }
 
-void
+string
 TextGenerator::generateln( const char *s )
-{ 
-  generate( s ) ;
-  (*sout) << endl ; 
+{
+  reset();
+  output_ln(s);
+  return outstream.str();
 }
 
-void
+string
 TextGenerator::generateEntire( const char *s )
 {
+  reset();
   startTextGeneration() ;
-  generate_preproc(s) ;
+  preprocess(s) ;
   endTextGeneration() ;
+  return outstream.str();
 }
 
-void
+string
 TextGenerator::beginText( const char *s )
 {
+  reset();
   startTextGeneration() ;
   if ( s )
-    generate_preproc( s ) ;
+    preprocess( s ) ;
+  return outstream.str();
+}
+
+string
+TextGenerator::endText( const char *s )
+{
+  reset();
+  if ( s )
+    preprocess( s ) ;
+  endTextGeneration() ;
+  return outstream.str();
+}
+
+string
+TextGenerator::get_string()
+{
+  string ret = outstream.str();
+  reset();
+  return ret;
 }
 
 void
-TextGenerator::endText( const char *s )
+TextGenerator::startTextGeneration()
 {
-  if ( s )
-    generate_preproc( s ) ;
-  endTextGeneration() ;
+  output(pre_tag);
 }
 
+void
+TextGenerator::endTextGeneration()
+{
+  output(post_tag);
+}
