@@ -1,20 +1,20 @@
 /*
 ** Copyright (C) 1999, 2000, 2001 Lorenzo Bettini <bettini@gnu.org>
-**  
+**
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
 ** the Free Software Foundation; either version 2 of the License, or
 ** (at your option) any later version.
-**  
+**
 ** This program is distributed in the hope that it will be useful,
 ** but WITHOUT ANY WARRANTY; without even the implied warranty of
 ** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 ** GNU General Public License for more details.
-**  
+**
 ** You should have received a copy of the GNU General Public License
 ** along with this program; if not, write to the Free Software
 ** Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
-**  
+**
 */
 
 // textgen.h : Text Generator class
@@ -22,28 +22,46 @@
 #ifndef _TEXTGEN_H
 #define _TEXTGEN_H
 
+#include <string>
+#include "my_sstream.h"
+
 class CharTranslator;
 
 class TextGenerator
 {
+ private:
+   std::ostringstream outstream;
+   const std::string pre_tag;
+   const std::string post_tag;
+
  protected:
   CharTranslator *char_translator;
+  void output(const std::string &s);
+  void output_ln(const std::string &s = "");
+  void output(int i);
+  void preprocess(const char *s);
 
  public:
-  TextGenerator(CharTranslator *);
+  TextGenerator();
+  TextGenerator(const std::string &pre, const std::string &post);
+  virtual ~TextGenerator() {}
 
-  virtual void generate( const char *s );
-  virtual void generate( const char *s, int start, int end );
-  virtual void generate_preproc(const char *s);
+  virtual std::string generate( const char *s );
+  virtual std::string generate( const std::string &s, int start, int end );
+  virtual std::string generate_preproc(const char *s);
 
-  virtual void generateln( const char *s );
+  virtual std::string generateln( const char *s );
 
-  virtual void generateEntire( const char *s );
+  virtual std::string generateEntire( const char *s );
 
-  virtual void startTextGeneration() {}
-  virtual void endTextGeneration() {}
-  virtual void beginText( const char *s );
-  virtual void endText( const char *s );
+  virtual std::string beginText( const char *s );
+  virtual std::string endText( const char *s );
+
+  virtual void startTextGeneration();
+  virtual void endTextGeneration();
+
+  std::string get_string();
+  void reset();
 } ;
 
 #endif
