@@ -17,22 +17,23 @@
  *
  */
 
+#ifdef HAVE_CONFIG_H
+#include "config.h"
+#endif
+
+#include "startapp.h"
+
 #include <stdlib.h>
 #include <stdio.h>
 #include <iostream>
 #include <string.h>
 
-#ifdef HAVE_CONFIG_H
-#include "config.h"
-#endif
-
 #include "colors.h"
 #include "cmdline.h"
 #include "genfun.h"
 #include "fileutil.h"
 #include "messages.h"
 
-#include "startapp.h"
 #include "copyright.h"
 #include "reportbugs.h"
 #include "parsetags.h"
@@ -49,6 +50,9 @@
 #include "cmdlineargs.h"
 #include "generators.h"
 #include "globalcolormap.h"
+#include "maingeneratorfactory.h"
+#include "mainoutputbuffer.h"
+#include "mainoutputgenerator.h"
 
 using std::cout;
 using std::endl;
@@ -180,7 +184,7 @@ StartApp::start(int argc, char * argv[])
 
   parseTags() ;
 
-  GeneratorFactory *generator_factory = 0;
+  outputbuffer = new OutputBuffer;
 
   if (format_esc)
     {
@@ -190,8 +194,13 @@ StartApp::start(int argc, char * argv[])
           exit (1);
         }
 
-      generator_factory = new EscGeneratorFactory
-        (args_info.line_number_given);
+      if (args_info.line_number_ref_given)
+        {
+          cerr << PACKAGE << ": cannot generate line references in esc output format" << endl;
+          exit (1);
+        }
+
+      generator_factory = new EscGeneratorFactory;
     }
   else
     {
@@ -220,8 +229,7 @@ StartApp::start(int argc, char * argv[])
      if( use_css )
        {
          generator_factory =
-           new CssGeneratorFactory (args_info.line_number_given,
-                                    title, args_info.line_number_ref_given,
+           new CssGeneratorFactory (title,
                                     input_name, doc_header,
                                     doc_footer, css_url);
        }
@@ -230,14 +238,14 @@ StartApp::start(int argc, char * argv[])
          if (format_xhtml && ! args_info.css_given)
            generator_factory =
              new XHtmlGeneratorFactory
-              (args_info.line_number_given, title,
-               args_info.line_number_ref_given, input_name, doc_header,
+              (title,
+               input_name, doc_header,
                doc_footer, css_url);
          else
            generator_factory =
             new HtmlGeneratorFactory
-             (args_info.line_number_given, title,
-              args_info.line_number_ref_given, input_name, doc_header,
+             (title,
+              input_name, doc_header,
               doc_footer, css_url);
        }
      }
@@ -249,12 +257,18 @@ StartApp::start(int argc, char * argv[])
 
   // let's start the translation :-)
 
+  bool generate_line_num =
+    (args_info.line_number_given || args_info.line_number_ref_given);
+
   // first the --input file
-  if ( ! args_info.inputs_num )
+  if ( ! args_info.inputs_num ) {
     processFile( args_info.src_lang_arg, args_info.out_format_arg,
     		 inputFileName,
                  (generate_to_stdout ? 0 : outputFileName),
-                 entire_doc, gen_version ) ;
+                 entire_doc, gen_version,
+                 generate_line_num, args_info.line_number_ref_given) ;
+    outputbuffer->reset();
+  }
 
   // let's process other files, if there are any
   if ( args_info.inputs_num && !is_cgi ) {
@@ -264,11 +278,16 @@ StartApp::start(int argc, char * argv[])
                    (generate_to_stdout ? 0 :
                     (char *) (createOutputFileName (args_info.inputs[i],
                                                     args_info.output_dir_arg, ext)).c_str ()),
-		   entire_doc, gen_version) ;
+		   entire_doc, gen_version,
+                   generate_line_num, args_info.line_number_ref_given) ;
       cerr << "Processed " << args_info.inputs[i] << endl ;
+      outputbuffer->reset();
     }
   }
 
+  delete outputbuffer;
+  outputbuffer = 0;
+
   return (0 );
 }
 
