@@ -10,8 +10,8 @@
   or type source-highlight --help for the list of options
 
   written by
-  Lorenzo Bettini <bettini@gnu.org>
-  http://w3.newnet.it/bettini
+  Lorenzo Bettini
+  http://www.lorenzobettini.it
   http://www.gnu.org/software/src-highlite
 */
 
@@ -29,7 +29,7 @@ public class Hello {
 	// just some greetings ;-)  /*
 	System.out.println( "Hello from java2html :-)" ) ;
 	System.out.println( "\tby Lorenzo Bettini" ) ;
-	System.out.println( "\tbettini@gnu.org" ) ;
+	System.out.println( "\thttp://www.lorenzobettini.it" ) ;
         if (argc > 0)
             String param = argc[0];
         //System.out.println( "bye bye... :-D" ) ; // see you soon
