@@ -32,3 +32,11 @@ second one
 """
 'And here the fun starts'
 test()
+
+table = { 'S'  : ['5'],
+ 'a'  : ['4','a','@'],
+ 'b'  : ['8','B'],
+ "ps" : ["Pz"],
+ 'ss' : ['5S','S5'],
+ 'es' : ['3Z','3z'],
+ 'ou' : ['00'] }
